pub struct TypedLifecycle<K, F>{ /* private fields */ }Expand description
Helper for creating typed lifecycle implementations.
This wrapper provides convenient typed access to lifecycle events when you only use a single key type in your cache.
Example
use priority_lfu::{TypedLifecycle, CacheBuilder, CacheKey, DeepSizeOf};
use std::sync::atomic::{AtomicUsize, Ordering};
use std::sync::Arc;
#[derive(Hash, Eq, PartialEq, Clone)]
struct MyKey(u64);
#[derive(Clone, DeepSizeOf)]
struct MyValue(String);
impl CacheKey for MyKey {
type Value = MyValue;
}
let evict_count = Arc::new(AtomicUsize::new(0));
let counter = evict_count.clone();
let lifecycle = TypedLifecycle::<MyKey, _>::new(move |_key| {
counter.fetch_add(1, Ordering::Relaxed);
});
let cache = CacheBuilder::new(1024)
.lifecycle(lifecycle)
.build();Implementations